# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datasphere.v2.jobs import jobs_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2
from yandex.cloud.datasphere.v2.jobs import project_job_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ProjectJobServiceStub(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Create',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Clone = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Clone',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Execute = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Execute',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Cancel = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Cancel',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReadStdLogs = channel.unary_stream(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadStdLogs',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.FromString,
                )
        self.ReadLogs = channel.unary_stream(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadLogs',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.FromString,
                )
        self.DownloadJobFiles = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DownloadJobFiles',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/List',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Get',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Delete',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteData = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteData',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteAllData = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteAllData',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.SetDataTtl = channel.unary_unary(
                '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/SetDataTtl',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.FromString,
                )


class ProjectJobServiceServicer(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    def Create(self, request, context):
        """Creates job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Clone(self, request, context):
        """Clone job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Execute(self, request, context):
        """Runs job execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Cancels running job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadStdLogs(self, request, context):
        """Returns stream of job logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadLogs(self, request, context):
        """Returns stream of job logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadJobFiles(self, request, context):
        """Returns download urls for job files.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns job by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteData(self, request, context):
        """Delete job data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAllData(self, request, context):
        """Delete all jobs data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDataTtl(self, request, context):
        """Update job data ttl.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectJobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Clone': grpc.unary_unary_rpc_method_handler(
                    servicer.Clone,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Execute': grpc.unary_unary_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReadStdLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadStdLogs,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.SerializeToString,
            ),
            'ReadLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.ReadLogs,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.SerializeToString,
            ),
            'DownloadJobFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadJobFiles,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteData,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteAllData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAllData,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetDataTtl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDataTtl,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v2.jobs.ProjectJobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectJobService(object):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Create',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CreateProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Clone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Clone',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CloneProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Execute',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ExecuteProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Cancel',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.CancelProjectJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadStdLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadStdLogs',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobStdLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/ReadLogs',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ReadProjectJobLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadJobFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DownloadJobFiles',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DownloadProjectJobFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/List',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.ListProjectJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Get',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.GetProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2.Job.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/Delete',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteData',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteProjectJobDataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAllData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/DeleteAllData',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.DeleteAllProjectJobDataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDataTtl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v2.jobs.ProjectJobService/SetDataTtl',
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_project__job__service__pb2.SetProjectJobDataTtlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
