# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/billing/v1/budget.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x03\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.yandex.cloud.billing.v1.BudgetStatus\x12>\n\x0b\x63ost_budget\x18\x06 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12\x44\n\x0e\x65xpense_budget\x18\x07 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12\x44\n\x0e\x62\x61lance_budget\x18\x08 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\"\xd7\x02\n\x0e\x43ostBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xda\x02\n\x11\x45xpenseBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xc6\x01\n\x11\x42\x61lanceBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x16\n\x08\x65nd_date\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x11\x43onsumptionFilter\x12\x13\n\x0bservice_ids\x18\x01 \x03(\t\x12U\n\x15\x63loud_folders_filters\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.billing.v1.CloudFoldersConsumptionFilter\"E\n\x1d\x43loudFoldersConsumptionFilter\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x12\n\nfolder_ids\x18\x02 \x03(\t\"\x88\x01\n\rThresholdRule\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.billing.v1.ThresholdTypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x61mount\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x1dnotification_user_account_ids\x18\x03 \x03(\t*U\n\x0c\x42udgetStatus\x12\x1d\n\x19\x42UDGET_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03*\\\n\x0fResetPeriodType\x12!\n\x1dRESET_PERIOD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\x0b\n\x07QUARTER\x10\x02\x12\x0c\n\x08\x41NNUALLY\x10\x03*H\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\n\n\x06\x41MOUNT\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.budget_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _BUDGET.oneofs_by_name['budget_spec']._options = None
  _BUDGET.oneofs_by_name['budget_spec']._serialized_options = b'\300\3011\001'
  _COSTBUDGETSPEC.oneofs_by_name['start_type']._options = None
  _COSTBUDGETSPEC.oneofs_by_name['start_type']._serialized_options = b'\300\3011\001'
  _COSTBUDGETSPEC.fields_by_name['amount']._options = None
  _COSTBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _COSTBUDGETSPEC.fields_by_name['end_date']._options = None
  _COSTBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._options = None
  _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._serialized_options = b'\300\3011\001'
  _EXPENSEBUDGETSPEC.fields_by_name['amount']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _EXPENSEBUDGETSPEC.fields_by_name['end_date']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _BALANCEBUDGETSPEC.fields_by_name['amount']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _BALANCEBUDGETSPEC.fields_by_name['end_date']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _THRESHOLDRULE.fields_by_name['type']._options = None
  _THRESHOLDRULE.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _THRESHOLDRULE.fields_by_name['amount']._options = None
  _THRESHOLDRULE.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _globals['_BUDGETSTATUS']._serialized_start=1757
  _globals['_BUDGETSTATUS']._serialized_end=1842
  _globals['_RESETPERIODTYPE']._serialized_start=1844
  _globals['_RESETPERIODTYPE']._serialized_end=1936
  _globals['_THRESHOLDTYPE']._serialized_start=1938
  _globals['_THRESHOLDTYPE']._serialized_end=2010
  _globals['_BUDGET']._serialized_start=130
  _globals['_BUDGET']._serialized_end=520
  _globals['_COSTBUDGETSPEC']._serialized_start=523
  _globals['_COSTBUDGETSPEC']._serialized_end=866
  _globals['_EXPENSEBUDGETSPEC']._serialized_start=869
  _globals['_EXPENSEBUDGETSPEC']._serialized_end=1215
  _globals['_BALANCEBUDGETSPEC']._serialized_start=1218
  _globals['_BALANCEBUDGETSPEC']._serialized_end=1416
  _globals['_CONSUMPTIONFILTER']._serialized_start=1418
  _globals['_CONSUMPTIONFILTER']._serialized_end=1545
  _globals['_CLOUDFOLDERSCONSUMPTIONFILTER']._serialized_start=1547
  _globals['_CLOUDFOLDERSCONSUMPTIONFILTER']._serialized_end=1616
  _globals['_THRESHOLDRULE']._serialized_start=1619
  _globals['_THRESHOLDRULE']._serialized_end=1755
# @@protoc_insertion_point(module_scope)
