# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/ml_model_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import ml_model_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_ml__model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/mdb/clickhouse/v1/ml_model_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a-yandex/cloud/mdb/clickhouse/v1/ml_model.proto\"l\n\x11GetMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"u\n\x13ListMlModelsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x14ListMlModelsResponse\x12:\n\tml_models\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.clickhouse.v1.MlModel\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x01\n\x14\x43reateMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12?\n\x04type\x18\x03 \x01(\x0e\x32+.yandex.cloud.mdb.clickhouse.v1.MlModelTypeB\x04\xe8\xc7\x31\x01\x12\x11\n\x03uri\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"B\n\x15\x43reateMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t\"\xad\x01\n\x14UpdateMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0b\n\x03uri\x18\x04 \x01(\t\"B\n\x15UpdateMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t\"o\n\x14\x44\x65leteMlModelRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rml_model_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"B\n\x15\x44\x65leteMlModelMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rml_model_name\x18\x02 \x01(\t2\xff\x07\n\x0eMlModelService\x12\xb0\x01\n\x03Get\x12\x31.yandex.cloud.mdb.clickhouse.v1.GetMlModelRequest\x1a\'.yandex.cloud.mdb.clickhouse.v1.MlModel\"M\x82\xd3\xe4\x93\x02G\x12\x45/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}\x12\xb0\x01\n\x04List\x12\x33.yandex.cloud.mdb.clickhouse.v1.ListMlModelsRequest\x1a\x34.yandex.cloud.mdb.clickhouse.v1.ListMlModelsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-clickhouse/v1/clusters/{cluster_id}/mlModels\x12\xc7\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.clickhouse.v1.CreateMlModelRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2* \n\x15\x43reateMlModelMetadata\x12\x07MlModel\x82\xd3\xe4\x93\x02:\"5/managed-clickhouse/v1/clusters/{cluster_id}/mlModels:\x01*\x12\xd7\x01\n\x06Update\x12\x34.yandex.cloud.mdb.clickhouse.v1.UpdateMlModelRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2* \n\x15UpdateMlModelMetadata\x12\x07MlModel\x82\xd3\xe4\x93\x02J2E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}:\x01*\x12\xe2\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.clickhouse.v1.DeleteMlModelRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*.\n\x15\x44\x65leteMlModelMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.ml_model_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _GETMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _GETMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _GETMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTMLMODELSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTMLMODELSREQUEST.fields_by_name['page_size']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTMLMODELSREQUEST.fields_by_name['page_token']._options = None
  _LISTMLMODELSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATEMLMODELREQUEST.fields_by_name['type']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CREATEMLMODELREQUEST.fields_by_name['uri']._options = None
  _CREATEMLMODELREQUEST.fields_by_name['uri']._serialized_options = b'\350\3071\001'
  _UPDATEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _UPDATEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETEMLMODELREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEMLMODELREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEMLMODELREQUEST.fields_by_name['ml_model_name']._options = None
  _DELETEMLMODELREQUEST.fields_by_name['ml_model_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _MLMODELSERVICE.methods_by_name['Get']._options = None
  _MLMODELSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002G\022E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}'
  _MLMODELSERVICE.methods_by_name['List']._options = None
  _MLMODELSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0027\0225/managed-clickhouse/v1/clusters/{cluster_id}/mlModels'
  _MLMODELSERVICE.methods_by_name['Create']._options = None
  _MLMODELSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateMlModelMetadata\022\007MlModel\202\323\344\223\002:\"5/managed-clickhouse/v1/clusters/{cluster_id}/mlModels:\001*'
  _MLMODELSERVICE.methods_by_name['Update']._options = None
  _MLMODELSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateMlModelMetadata\022\007MlModel\202\323\344\223\002J2E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}:\001*'
  _MLMODELSERVICE.methods_by_name['Delete']._options = None
  _MLMODELSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteMlModelMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/managed-clickhouse/v1/clusters/{cluster_id}/mlModels/{ml_model_name}'
  _globals['_GETMLMODELREQUEST']._serialized_start=305
  _globals['_GETMLMODELREQUEST']._serialized_end=413
  _globals['_LISTMLMODELSREQUEST']._serialized_start=415
  _globals['_LISTMLMODELSREQUEST']._serialized_end=532
  _globals['_LISTMLMODELSRESPONSE']._serialized_start=534
  _globals['_LISTMLMODELSRESPONSE']._serialized_end=641
  _globals['_CREATEMLMODELREQUEST']._serialized_start=644
  _globals['_CREATEMLMODELREQUEST']._serialized_end=839
  _globals['_CREATEMLMODELMETADATA']._serialized_start=841
  _globals['_CREATEMLMODELMETADATA']._serialized_end=907
  _globals['_UPDATEMLMODELREQUEST']._serialized_start=910
  _globals['_UPDATEMLMODELREQUEST']._serialized_end=1083
  _globals['_UPDATEMLMODELMETADATA']._serialized_start=1085
  _globals['_UPDATEMLMODELMETADATA']._serialized_end=1151
  _globals['_DELETEMLMODELREQUEST']._serialized_start=1153
  _globals['_DELETEMLMODELREQUEST']._serialized_end=1264
  _globals['_DELETEMLMODELMETADATA']._serialized_start=1266
  _globals['_DELETEMLMODELMETADATA']._serialized_end=1332
  _globals['_MLMODELSERVICE']._serialized_start=1335
  _globals['_MLMODELSERVICE']._serialized_end=2358
# @@protoc_insertion_point(module_scope)
