# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/hba_rule_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.greenplum.v1 import hba_rule_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_hba__rule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/greenplum/v1/hba_rule_service.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/greenplum/v1/hba_rule.proto\"x\n\x14\x43reateHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08hba_rule\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x04\xe8\xc7\x31\x01\"x\n\x14UpdateHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08hba_rule\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x04\xe8\xc7\x31\x01\"V\n\x14\x44\x65leteHBARuleRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x08priority\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\"7\n\x13ListHBARulesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"[\n\x1dListHBARulesAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x08revision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"Q\n\x14ListHBARulesResponse\x12\x39\n\thba_rules\x18\x01 \x03(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARule\"\x81\x01\n\x1a\x42\x61tchUpdateHBARulesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\thba_rules\x18\x02 \x03(\x0b\x32&.yandex.cloud.mdb.greenplum.v1.HBARuleB\x06\x82\xc8\x31\x02>0\"&\n\x10HBARulesMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t2\xf1\t\n\x0eHBARuleService\x12\xad\x01\n\x04List\x12\x32.yandex.cloud.mdb.greenplum.v1.ListHBARulesRequest\x1a\x33.yandex.cloud.mdb.greenplum.v1.ListHBARulesResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/managed-greenplum/v1/clusters/{cluster_id}/hbaRules\x12\xcc\x01\n\x0eListAtRevision\x12<.yandex.cloud.mdb.greenplum.v1.ListHBARulesAtRevisionRequest\x1a\x33.yandex.cloud.mdb.greenplum.v1.ListHBARulesResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/managed-greenplum/v1/clusters/{cluster_id}/hbaRules/atRevision\x12\xce\x01\n\x06\x43reate\x12\x33.yandex.cloud.mdb.greenplum.v1.CreateHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\x01*\x12\xce\x01\n\x06Update\x12\x33.yandex.cloud.mdb.greenplum.v1.UpdateHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\x32\x34/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.mdb.greenplum.v1.DeleteHBARuleRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/managed-greenplum/v1/clusters/{cluster_id}/hbaRule/{priority}\x12\xe5\x01\n\x0b\x42\x61tchUpdate\x12\x39.yandex.cloud.mdb.greenplum.v1.BatchUpdateHBARulesRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*)\n\x10HBARulesMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:batchUpdate:\x01*Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _CREATEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEHBARULEREQUEST.fields_by_name['hba_rule']._options = None
  _CREATEHBARULEREQUEST.fields_by_name['hba_rule']._serialized_options = b'\350\3071\001'
  _UPDATEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEHBARULEREQUEST.fields_by_name['hba_rule']._options = None
  _UPDATEHBARULEREQUEST.fields_by_name['hba_rule']._serialized_options = b'\350\3071\001'
  _DELETEHBARULEREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEHBARULEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEHBARULEREQUEST.fields_by_name['priority']._options = None
  _DELETEHBARULEREQUEST.fields_by_name['priority']._serialized_options = b'\372\3071\0060-1000'
  _LISTHBARULESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTHBARULESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['cluster_id']._options = None
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['revision']._options = None
  _LISTHBARULESATREVISIONREQUEST.fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['cluster_id']._options = None
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['hba_rules']._options = None
  _BATCHUPDATEHBARULESREQUEST.fields_by_name['hba_rules']._serialized_options = b'\202\3101\002>0'
  _HBARULESERVICE.methods_by_name['List']._options = None
  _HBARULESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0026\0224/managed-greenplum/v1/clusters/{cluster_id}/hbaRules'
  _HBARULESERVICE.methods_by_name['ListAtRevision']._options = None
  _HBARULESERVICE.methods_by_name['ListAtRevision']._serialized_options = b'\202\323\344\223\002A\022?/managed-greenplum/v1/clusters/{cluster_id}/hbaRules/atRevision'
  _HBARULESERVICE.methods_by_name['Create']._options = None
  _HBARULESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\001*'
  _HBARULESERVICE.methods_by_name['Update']._options = None
  _HBARULESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002924/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:\001*'
  _HBARULESERVICE.methods_by_name['Delete']._options = None
  _HBARULESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/managed-greenplum/v1/clusters/{cluster_id}/hbaRule/{priority}'
  _HBARULESERVICE.methods_by_name['BatchUpdate']._options = None
  _HBARULESERVICE.methods_by_name['BatchUpdate']._serialized_options = b'\262\322*)\n\020HBARulesMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/managed-greenplum/v1/clusters/{cluster_id}/hbaRules:batchUpdate:\001*'
  _globals['_CREATEHBARULEREQUEST']._serialized_start=268
  _globals['_CREATEHBARULEREQUEST']._serialized_end=388
  _globals['_UPDATEHBARULEREQUEST']._serialized_start=390
  _globals['_UPDATEHBARULEREQUEST']._serialized_end=510
  _globals['_DELETEHBARULEREQUEST']._serialized_start=512
  _globals['_DELETEHBARULEREQUEST']._serialized_end=598
  _globals['_LISTHBARULESREQUEST']._serialized_start=600
  _globals['_LISTHBARULESREQUEST']._serialized_end=655
  _globals['_LISTHBARULESATREVISIONREQUEST']._serialized_start=657
  _globals['_LISTHBARULESATREVISIONREQUEST']._serialized_end=748
  _globals['_LISTHBARULESRESPONSE']._serialized_start=750
  _globals['_LISTHBARULESRESPONSE']._serialized_end=831
  _globals['_BATCHUPDATEHBARULESREQUEST']._serialized_start=834
  _globals['_BATCHUPDATEHBARULESREQUEST']._serialized_end=963
  _globals['_HBARULESMETADATA']._serialized_start=965
  _globals['_HBARULESMETADATA']._serialized_end=1003
  _globals['_HBARULESERVICE']._serialized_start=1006
  _globals['_HBARULESERVICE']._serialized_end=2271
# @@protoc_insertion_point(module_scope)
