# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import clickhouse_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_clickhouse__pb2
from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2
from yandex.cloud.datatransfer.v1.endpoint import kafka_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_kafka__pb2
from yandex.cloud.datatransfer.v1.endpoint import metrika_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_metrika__pb2
from yandex.cloud.datatransfer.v1.endpoint import mongo_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_mongo__pb2
from yandex.cloud.datatransfer.v1.endpoint import mysql_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_mysql__pb2
from yandex.cloud.datatransfer.v1.endpoint import postgres_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_postgres__pb2
from yandex.cloud.datatransfer.v1.endpoint import ydb_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_ydb__pb2
from yandex.cloud.datatransfer.v1.endpoint import yds_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_yds__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/datatransfer/v1/endpoint.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x36yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/kafka.proto\x1a\x33yandex/cloud/datatransfer/v1/endpoint/metrika.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/mongo.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/mysql.proto\x1a\x34yandex/cloud/datatransfer/v1/endpoint/postgres.proto\x1a/yandex/cloud/datatransfer/v1/endpoint/ydb.proto\x1a/yandex/cloud/datatransfer/v1/endpoint/yds.proto\"\x8d\x02\n\x08\x45ndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.datatransfer.v1.Endpoint.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x34\"\xd5\t\n\x10\x45ndpointSettings\x12J\n\x0cmysql_source\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MysqlSourceH\x00\x12P\n\x0fpostgres_source\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.PostgresSourceH\x00\x12\x46\n\nydb_source\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YdbSourceH\x00\x12\x46\n\nyds_source\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YDSSourceH\x00\x12J\n\x0ckafka_source\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.KafkaSourceH\x00\x12J\n\x0cmongo_source\x18\t \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MongoSourceH\x00\x12T\n\x11\x63lickhouse_source\x18\x10 \x01(\x0b\x32\x37.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSourceH\x00\x12J\n\x0cmysql_target\x18\x65 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MysqlTargetH\x00\x12P\n\x0fpostgres_target\x18\x66 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.PostgresTargetH\x00\x12T\n\x11\x63lickhouse_target\x18h \x01(\x0b\x32\x37.yandex.cloud.datatransfer.v1.endpoint.ClickhouseTargetH\x00\x12\x46\n\nydb_target\x18i \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YdbTargetH\x00\x12J\n\x0ckafka_target\x18n \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.KafkaTargetH\x00\x12J\n\x0cmongo_target\x18o \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MongoTargetH\x00\x12O\n\x0emetrika_source\x18\x92\x01 \x01(\x0b\x32\x34.yandex.cloud.datatransfer.v1.endpoint.MetrikaSourceH\x00\x12G\n\nyds_target\x18\x96\x01 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YDSTargetH\x00\x42\n\n\x08settingsJ\x04\x08\x04\x10\x07J\x04\x08\n\x10\x10J\x04\x08\x11\x10\x65J\x04\x08g\x10hJ\x04\x08j\x10nJ\x05\x08p\x10\x92\x01J\x06\x08\x93\x01\x10\x96\x01\x42q\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _ENDPOINT_LABELSENTRY._options = None
  _ENDPOINT_LABELSENTRY._serialized_options = b'8\001'
  _globals['_ENDPOINT']._serialized_start=544
  _globals['_ENDPOINT']._serialized_end=813
  _globals['_ENDPOINT_LABELSENTRY']._serialized_start=756
  _globals['_ENDPOINT_LABELSENTRY']._serialized_end=801
  _globals['_ENDPOINTSETTINGS']._serialized_start=816
  _globals['_ENDPOINTSETTINGS']._serialized_end=2053
# @@protoc_insertion_point(module_scope)
