# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/format_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/mdb/clickhouse/v1/format_schema.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\"}\n\x0c\x46ormatSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12>\n\x04type\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.mdb.clickhouse.v1.FormatSchemaType\x12\x0b\n\x03uri\x18\x04 \x01(\t*y\n\x10\x46ormatSchemaType\x12\"\n\x1e\x46ORMAT_SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46ORMAT_SCHEMA_TYPE_PROTOBUF\x10\x01\x12 \n\x1c\x46ORMAT_SCHEMA_TYPE_CAPNPROTO\x10\x02\x42s\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.format_schema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_FORMATSCHEMATYPE']._serialized_start=213
  _globals['_FORMATSCHEMATYPE']._serialized_end=334
  _globals['_FORMATSCHEMA']._serialized_start=86
  _globals['_FORMATSCHEMA']._serialized_end=211
# @@protoc_insertion_point(module_scope)
