# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/backup/v1/policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.backup.v1 import policy_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/backup/v1/policy_service.proto\x12\x16yandex.cloud.backup.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a#yandex/cloud/backup/v1/policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"O\n\x13ListPoliciesRequest\x12\x1b\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\"H\n\x14ListPoliciesResponse\x12\x30\n\x08policies\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.backup.v1.Policy\"\x92\x01\n\x13\x43reatePolicyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x03 \x01(\x0b\x32&.yandex.cloud.backup.v1.PolicySettingsB\x04\xe8\xc7\x31\x01\"7\n\x14\x43reatePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x10GetPolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"v\n\x13UpdatePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x02 \x01(\x0b\x32&.yandex.cloud.backup.v1.PolicySettingsB\x04\xe8\xc7\x31\x01\"7\n\x14UpdatePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x13\x44\x65letePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x14\x44\x65letePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"`\n\x12\x41pplyPolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n\x13\x41pplyPolicyMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\"n\n\x17ListApplicationsRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x13\n\tpolicy_id\x18\x02 \x01(\tH\x00\x12\x1d\n\x13\x63ompute_instance_id\x18\x03 \x01(\tH\x00\x42\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"[\n\x18ListApplicationsResponse\x12?\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32).yandex.cloud.backup.v1.PolicyApplication\"\\\n\x0e\x45xecuteRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"^\n\x0f\x45xecuteMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x1b\n\x13progress_percentage\x18\x03 \x01(\x01\"[\n\rRevokeRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x0eRevokeMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t2\xd7\x0b\n\rPolicyService\x12~\n\x04List\x12+.yandex.cloud.backup.v1.ListPoliciesRequest\x1a,.yandex.cloud.backup.v1.ListPoliciesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/backup/v1/policies\x12\x9a\x01\n\x06\x43reate\x12+.yandex.cloud.backup.v1.CreatePolicyRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reatePolicyMetadata\x12\x06Policy\x82\xd3\xe4\x93\x02\x18\"\x13/backup/v1/policies:\x01*\x12x\n\x03Get\x12(.yandex.cloud.backup.v1.GetPolicyRequest\x1a\x1e.yandex.cloud.backup.v1.Policy\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/backup/v1/policies/{policy_id}\x12\xa6\x01\n\x06Update\x12+.yandex.cloud.backup.v1.UpdatePolicyRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*\x1e\n\x14UpdatePolicyMetadata\x12\x06Policy\x82\xd3\xe4\x93\x02$2\x1f/backup/v1/policies/{policy_id}:\x01*\x12\xb2\x01\n\x06\x44\x65lete\x12+.yandex.cloud.backup.v1.DeletePolicyRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*-\n\x14\x44\x65letePolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/backup/v1/policies/{policy_id}\x12\xb8\x01\n\x05\x41pply\x12*.yandex.cloud.backup.v1.ApplyPolicyRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*,\n\x13\x41pplyPolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02*\"%/backup/v1/policies/{policy_id}:apply:\x01*\x12\xab\x01\n\x10ListApplications\x12/.yandex.cloud.backup.v1.ListApplicationsRequest\x1a\x30.yandex.cloud.backup.v1.ListApplicationsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/backup/v1/policies/{policy_id}/applications\x12\xb4\x01\n\x07\x45xecute\x12&.yandex.cloud.backup.v1.ExecuteRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*(\n\x0f\x45xecuteMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02,\"\'/backup/v1/policies/{policy_id}:execute:\x01*\x12\xb0\x01\n\x06Revoke\x12%.yandex.cloud.backup.v1.RevokeRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\'\n\x0eRevokeMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+\"&/backup/v1/policies/{policy_id}:revoke:\x01*B_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.policy_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _LISTPOLICIESREQUEST.fields_by_name['folder_id']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['settings']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _CREATEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _CREATEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _GETPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPOLICYREQUEST.fields_by_name['settings']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _UPDATEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _UPDATEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _DELETEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _APPLYPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _APPLYPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _APPLYPOLICYREQUEST.fields_by_name['compute_instance_id']._options = None
  _APPLYPOLICYREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTAPPLICATIONSREQUEST.oneofs_by_name['id']._options = None
  _LISTAPPLICATIONSREQUEST.oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _EXECUTEREQUEST.fields_by_name['policy_id']._options = None
  _EXECUTEREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _EXECUTEREQUEST.fields_by_name['compute_instance_id']._options = None
  _EXECUTEREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEREQUEST.fields_by_name['policy_id']._options = None
  _REVOKEREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEREQUEST.fields_by_name['compute_instance_id']._options = None
  _REVOKEREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _POLICYSERVICE.methods_by_name['List']._options = None
  _POLICYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/backup/v1/policies'
  _POLICYSERVICE.methods_by_name['Create']._options = None
  _POLICYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreatePolicyMetadata\022\006Policy\202\323\344\223\002\030\"\023/backup/v1/policies:\001*'
  _POLICYSERVICE.methods_by_name['Get']._options = None
  _POLICYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/backup/v1/policies/{policy_id}'
  _POLICYSERVICE.methods_by_name['Update']._options = None
  _POLICYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdatePolicyMetadata\022\006Policy\202\323\344\223\002$2\037/backup/v1/policies/{policy_id}:\001*'
  _POLICYSERVICE.methods_by_name['Delete']._options = None
  _POLICYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeletePolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/backup/v1/policies/{policy_id}'
  _POLICYSERVICE.methods_by_name['Apply']._options = None
  _POLICYSERVICE.methods_by_name['Apply']._serialized_options = b'\262\322*,\n\023ApplyPolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002*\"%/backup/v1/policies/{policy_id}:apply:\001*'
  _POLICYSERVICE.methods_by_name['ListApplications']._options = None
  _POLICYSERVICE.methods_by_name['ListApplications']._serialized_options = b'\202\323\344\223\002.\022,/backup/v1/policies/{policy_id}/applications'
  _POLICYSERVICE.methods_by_name['Execute']._options = None
  _POLICYSERVICE.methods_by_name['Execute']._serialized_options = b'\262\322*(\n\017ExecuteMetadata\022\025google.protobuf.Empty\202\323\344\223\002,\"\'/backup/v1/policies/{policy_id}:execute:\001*'
  _POLICYSERVICE.methods_by_name['Revoke']._options = None
  _POLICYSERVICE.methods_by_name['Revoke']._serialized_options = b'\262\322*\'\n\016RevokeMetadata\022\025google.protobuf.Empty\202\323\344\223\002+\"&/backup/v1/policies/{policy_id}:revoke:\001*'
  _globals['_LISTPOLICIESREQUEST']._serialized_start=243
  _globals['_LISTPOLICIESREQUEST']._serialized_end=322
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=324
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=396
  _globals['_CREATEPOLICYREQUEST']._serialized_start=399
  _globals['_CREATEPOLICYREQUEST']._serialized_end=545
  _globals['_CREATEPOLICYMETADATA']._serialized_start=547
  _globals['_CREATEPOLICYMETADATA']._serialized_end=602
  _globals['_GETPOLICYREQUEST']._serialized_start=604
  _globals['_GETPOLICYREQUEST']._serialized_end=655
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=657
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=775
  _globals['_UPDATEPOLICYMETADATA']._serialized_start=777
  _globals['_UPDATEPOLICYMETADATA']._serialized_end=832
  _globals['_DELETEPOLICYREQUEST']._serialized_start=834
  _globals['_DELETEPOLICYREQUEST']._serialized_end=888
  _globals['_DELETEPOLICYMETADATA']._serialized_start=890
  _globals['_DELETEPOLICYMETADATA']._serialized_end=945
  _globals['_APPLYPOLICYREQUEST']._serialized_start=947
  _globals['_APPLYPOLICYREQUEST']._serialized_end=1043
  _globals['_APPLYPOLICYMETADATA']._serialized_start=1045
  _globals['_APPLYPOLICYMETADATA']._serialized_end=1114
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=1116
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=1226
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=1228
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=1319
  _globals['_EXECUTEREQUEST']._serialized_start=1321
  _globals['_EXECUTEREQUEST']._serialized_end=1413
  _globals['_EXECUTEMETADATA']._serialized_start=1415
  _globals['_EXECUTEMETADATA']._serialized_end=1509
  _globals['_REVOKEREQUEST']._serialized_start=1511
  _globals['_REVOKEREQUEST']._serialized_end=1602
  _globals['_REVOKEMETADATA']._serialized_start=1604
  _globals['_REVOKEMETADATA']._serialized_end=1668
  _globals['_POLICYSERVICE']._serialized_start=1671
  _globals['_POLICYSERVICE']._serialized_end=3166
# @@protoc_insertion_point(module_scope)
